from .saucenao_api import SauceNao
from .containers import BasicSauce, BookSauce, VideoSauce


__author__ = 'nomnoms12'
__copyright__ = 'Copyright 2020, Taiga.sh Development'
__credits__ = ['nomnoms12', 'FujiMakoto']
__license__ = 'GNU General Public License v3.0'
__version__ = '1.0.2'
__maintainer__ = 'nomnoms12'
__email__ = 'alexander.ign0918@gmail.com'
__status__ = 'Production'



import enum


class DB(enum.auto):
    HMagazines = 0
    HGame_CG = 2
    DoujinshiDB = 3         # Not worked?
    Pixiv_Images = 5
    Nico_Nico_Seiga = 8
    Danbooru = 9
    Drawr_Images = 10
    Nijie_Images = 11
    Yandere = 12
    Openingsmoe = 13        # Not worked?
    Shutterstock = 15       # Not worked?
    FAKKU = 16
    HMisc = 18
    TwoDMarket = 19         # Not worked?
    MediBang = 20
    Anime = 21
    HAnime = 22
    Movies = 23
    Shows = 24
    Gelbooru = 25
    Konachan = 26
    SankakuChannel = 27
    AnimePicturesnet = 28   # Not worked?
    E621net = 29
    IdolComplex = 30
    Bcynet_Illust = 31
    Bcynet_Cosplay = 32
    PortalGraphicsnet = 33
    DeviantArt = 34
    Pawoonet = 35
    Madokami = 36
    MangaDex = 37
    ALL = 999


class Hide(enum.auto):
    NONE = 0
    KNOWN = 1
    SUSPECTED = 2
    ALL = 3


class Bgcolor(enum.auto):
    NONE = 'none'
    WHITE = 'white'
    BLACK = 'black'
    GREY = 'grey'


class _OutputType(enum.auto):
    HTML = 0
    XML = 1
    JSON = 2



import setuptools


with open('README.md', encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name='saucenao_api',
    version='1.0.2',
    author='nomnoms12',
    author_email='alexander.ign0918@gmail.com',
    description='Wrapper for SauceNAO JSON API',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/nomnoms12/saucenao_api/',
    packages=['saucenao_api'],
    classifiers=[
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: OS Independent',
    ],
    python_requires='>= 3.6',
    install_requires=[
        'requests ~= 2.23.0',
    ],
    extras_require={
        'test': [
            'responses ~= 0.10.14',
            'pytest ~= 5.4.2',
            'pytest-cov ~= 2.8.1',
            'coveralls ~= 2.0.0',
        ],
    },
    project_urls={
       'Bug Reports': 'https://github.com/nomnoms12/saucenao_api/issues/',
       'Source': 'https://github.com/nomnoms12/saucenao_api/',
    },
)
